# Universal-Translator

Parallel multi-lingual translator with multi-embedding and multi-head seq2seq transformer. Using the same transformer for any pair of languages helps to have a better word and sentence representation across different languages, thus I call it universal translator.

## Installation
```
git clone https://github.com/s-omranpour/Universal-Translator
cd Universal-Translator/
pip install .
```

## Usage
Please visit examples directory. I used ALT dataset as an easy-to-use parallel corpora for multi-lingual translation. </br>
Download the dataset from [here](https://www2.nict.go.jp/astrec-att/member/mutiyama/ALT/ALT-Parallel-Corpus-20191206.zip)
